OC.L10N.register(
    "core",
    {
    "Please select a file." : "Proszę wybrać plik",
    "File is too big" : "Plik jest za duży",
    "Invalid file provided" : "Podano błędny plik",
    "No image or file provided" : "Brak obrazu lub pliku dostarczonego",
    "Unknown filetype" : "Nieznany typ pliku",
    "Invalid image" : "Nieprawidłowe zdjęcie",
    "An error occurred. Please contact your admin." : "Pojawił się błąd. Skontaktuj się z administratorem.",
    "No temporary profile picture available, try again" : "Brak obrazka profilu tymczasowego, spróbuj ponownie",
    "No crop data provided" : "Brak danych do przycięcia",
    "No valid crop data provided" : "Brak danych do przycięcia",
    "Crop is not square" : "Przycięcie nie jest prostokątem",
    "Couldn't reset password because the token is invalid" : "Nie można zresetować hasła, ponieważ token jest niepoprawny",
    "Couldn't reset password because the token is expired" : "Nie można zresetować hasła, ponieważ token wygasł",
    "%s password changed successfully" : "%s hasło zmieniono pomyślnie",
    "%s password reset" : "%s reset hasła",
    "Couldn't send reset email. Please contact your administrator." : "Nie mogę wysłać maila resetującego. Skontaktuj się z administratorem.",
    "Couldn't send mail to following users: %s " : "Nie można było wysłać wiadomości do następujących użytkowników: %s",
    "Preparing update" : "Przygotowuję aktualizację",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair warning: " : "Ostrzeżenie naprawiania:",
    "Repair error: " : "Błąd naprawiania:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Użyj aktualizatora z linii poleceń, ponieważ automatyczna aktualizacja jest zablokowana w config.php.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Sprawdzanie tabeli %s",
    "Turned on maintenance mode" : "Włączony tryb konserwacji",
    "Turned off maintenance mode" : "Wyłączony tryb konserwacji",
    "Maintenance mode is kept active" : "Tryb konserwacji pozostaje aktywny",
    "Updating database schema" : "Aktualizacja schematu bazy danych",
    "Updated database" : "Zaktualizuj bazę",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Sprawdzam czy schemat bazy danych może zostać zaktualizowany (to może zająć sporo czasu i zależy od rozmiaru bazy danych)",
    "Checked database schema update" : "Sprawdzono aktualizację schematu bazy danych",
    "Checking updates of apps" : "Sprawdzam aktualizacje aplikacji",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Sprawdzam czy schemat bazy danych %s może zostać zaktualizowany (to może zająć sporo czasu i zależy od rozmiaru bazy danych)",
    "Checked database schema update for apps" : "Sprawdzono aktualizację schematu bazy danych dla aplikacji",
    "Updated \"%s\" to %s" : "Zaktualizowano \"%s\" do %s",
    "Set log level to debug" : "Ustaw poziom logowania na debug",
    "Reset log level" : "Zresetuj poziom logowania",
    "Starting code integrity check" : "Rozpoczynam sprawdzanie spójności kodu",
    "Finished code integrity check" : "Zakończono sprawdzanie spójności kodu",
    "%s (3rdparty)" : "%s (od innych)",
    "%s (incompatible)" : "%s (niekompatybilne)",
    "Following apps have been disabled: %s" : "Poniższe aplikacje zostały wyłączone: %s",
    "Already up to date" : "Już zaktualizowano",
    "Sunday" : "Niedziela",
    "Monday" : "Poniedziałek",
    "Tuesday" : "Wtorek",
    "Wednesday" : "Środa",
    "Thursday" : "Czwartek",
    "Friday" : "Piątek",
    "Saturday" : "Sobota",
    "Sun." : "N.",
    "Mon." : "Pn.",
    "Tue." : "Wt.",
    "Wed." : "Śr.",
    "Thu." : "Cz.",
    "Fri." : "Pt.",
    "Sat." : "S.",
    "Su" : "Nd",
    "Mo" : "Pn",
    "Tu" : "Wt",
    "We" : "Śr",
    "Th" : "Czw",
    "Fr" : "Pt",
    "Sa" : "So",
    "January" : "Styczeń",
    "February" : "Luty",
    "March" : "Marzec",
    "April" : "Kwiecień",
    "May" : "Maj",
    "June" : "Czerwiec",
    "July" : "Lipiec",
    "August" : "Sierpień",
    "September" : "Wrzesień",
    "October" : "Październik",
    "November" : "Listopad",
    "December" : "Grudzień",
    "Jan." : "Sty.",
    "Feb." : "Lut.",
    "Mar." : "Mar.",
    "Apr." : "Kwi.",
    "May." : "Maj.",
    "Jun." : "Cze.",
    "Jul." : "Lip.",
    "Aug." : "Sie.",
    "Sep." : "Wrz.",
    "Oct." : "Paź.",
    "Nov." : "Lis.",
    "Dec." : "Gru.",
    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Sprawdzenie spójności kodu nie wykazało problemów. Więcej informacji…</a>",
    "Settings" : "Ustawienia",
    "Problem loading page, reloading in 5 seconds" : "Błąd podczas ładowania strony, odświeżanie w ciągu 5 sekund.",
    "Saving..." : "Zapisywanie...",
    "Dismiss" : "Anuluj",
    "seconds ago" : "sekund temu",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Link do zresetowanego hasła, został wysłany na twój adres e-mail. Jeśli nie dostałeś wiadomości w rozsądnym czasie, sprawdź folder ze spamem.<br> Jeśli nie ma wiadomości w tym folderze, skontaktuj się ze swoim administratorem.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Twoje pliki są zaszyfrowane. Jeśli nie włączyłeś klucza odzyskiwania, nie będzie możliwości odszyfrowania tych plików po zresetowaniu hasła.<br>Jeśli nie jesteś pewien co zrobić, skontaktuj się ze swoim administratorem, zanim bedziesz kontynuował. <br/> Czy chcesz kontynuować?\n ",
    "I know what I'm doing" : "Wiem co robię",
    "Password can not be changed. Please contact your administrator." : "Hasło nie może zostać zmienione. Skontaktuj się z administratorem.",
    "No" : "Nie",
    "Yes" : "Tak",
    "Choose" : "Wybierz",
    "Error loading file picker template: {error}" : "Błąd podczas ładowania pliku wybranego szablonu: {error}",
    "Ok" : "OK",
    "Error loading message template: {error}" : "Błąd podczas ładowania szablonu wiadomości: {error}",
    "read-only" : "tylko odczyt",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} konfliktów plików","{count} konfliktów plików","{count} konfliktów plików","{count} konfliktów plików"],
    "One file conflict" : "Konflikt pliku",
    "New Files" : "Nowe pliki",
    "Already existing files" : "Już istniejące pliki",
    "Which files do you want to keep?" : "Które pliki chcesz zachować?",
    "If you select both versions, the copied file will have a number added to its name." : "Jeśli wybierzesz obie wersje, skopiowany plik będzie miał dodany numerek w nazwie",
    "Cancel" : "Anuluj",
    "Continue" : "Kontynuuj ",
    "(all selected)" : "(wszystkie zaznaczone)",
    "({count} selected)" : "({count} zaznaczonych)",
    "Error loading file exists template" : "Błąd podczas ładowania szablonu istniejącego pliku",
    "Very weak password" : "Bardzo słabe hasło",
    "Weak password" : "Słabe hasło",
    "So-so password" : "Mało skomplikowane hasło",
    "Good password" : "Dobre hasło",
    "Strong password" : "Mocne hasło",
    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Serwer WWW nie jest jeszcze na tyle poprawnie skonfigurowany, aby umożliwić synchronizację plików, ponieważ interfejs WebDAV wydaje się być uszkodzony.",
    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Serwer WWW nie jest poprawnie skonfigurowany, aby wyświetlić \"{url}\". Więcej informacji można znaleźć w naszej <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentacji</a>.",
    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Ten serwer nie jest podłączony do internetu. Oznacza to, że niektóre funkcje tj.  montowanie zewnętrznych dysków, powiadomienia o aktualizacjach, instalacja dodatkowych aplikacji nie będą działały. Nie będzie działał również zdalny dostęp do plików oraz wysyłanie powiadomień e-mail. Jeżeli chcesz mieć dostęp do wszystkich funkcji zapewnij dostępu do internetu dla tego serwera. ",
    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Nie skonfigurowano pamięci podręcznej. W celu zwiększenia wydajności skonfiguruj memcache, o ile jest dostępne. Więcej informacji można znaleźć w <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentacji</a>.",
    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "/dev/urandom nie ma uprawnień do odczytu dla PHP, co nie jest zalecane z powodów bezpieczeństwa. Więcej informacji można znaleźć w <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentacji</a>.",
    "Error occurred while checking server setup" : "Pojawił się błąd podczas sprawdzania ustawień serwera",
    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Twój katalog danych oraz pliki prawdopodobnie są dostępne w sieci internet. Plik .htaccess nie działa prawidłowo. Sugerujemy wykonanie prawidłowej konfiguracji serwera web w taki sposób, aby Twój katalog danych nie był dłużej dostępny w internecie. Możesz także przenieść swój katalog danych poza obszar, z którego korzysta serwer web.",
    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "Nagłówek HTTP \"{header}\" nie jest skonfigurowany, tak jak \"{expected}\". Stanowi to potencjalne zagrożenie dla bezpieczeństwa i prywatności, w związku z czym rekomendujemy dostosowanie tego ustawienia.",
    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "Nagłówek HTTP \"Strict-Transport-Security\" nie jest skonfigurowany z minimalną wartością wymaganą przez parametr \"{seconds}\". Dla zwiększenia bezpieczeństwa rekomendujemy włączenie HSTS, co zostało opisane w naszych <a href=\"{docUrl}\" rel=\"noreferrer\">wskazówkach bezpieczeństwa</a>.",
    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Aktualnie korzystasz z tej strony przez HTTP. Zalecamy skonfigurowanie serwera w taki sposób, aby można było z niego korzystać przez HTTPS. Zapoznaj się ze wskazówkami bezpieczeństwa opisanymi w naszej dokumentacji <a href=\"{docUrl}\">security tips</a>.",
    "Shared" : "Udostępniono",
    "Shared with {recipients}" : "Współdzielony z {recipients}",
    "Error" : "Błąd",
    "Error while sharing" : "Błąd podczas współdzielenia",
    "Error while unsharing" : "Błąd podczas zatrzymywania współdzielenia",
    "The public link will expire no later than {days} days after it is created" : "Link publiczny wygaśnie nie później niż po {days} dniach od utworzenia",
    "Set expiration date" : "Ustaw datę wygaśnięcia",
    "Expiration" : "Wygaśnięcie",
    "Expiration date" : "Data wygaśnięcia",
    "Expiration date is required" : "Wymagana data wygaśnięcia",
    "Delete {link}" : "Usuń {link}",
    "Remove link" : "Usuń link",
    "{fileName} link" : "{nazwaPliku} link",
    "Link" : "Odnośnik",
    "Create public link" : "Utwórz link publiczny",
    "Edit" : "Edytuj",
    "Remove" : "Usuń",
    "Click to copy to clipboard" : "Kliknij żeby skopiować do schowka",
    "Social share" : "Społeczny udział",
    "There are currently no link shares, you can create one" : "Aktualnie brak udostępnianych linków, możesz stworzyć jakiś.",
    "Anyone with the link has access to the file/folder" : "Każdy posiadający link ma dostęp do pliku/katalogu.",
    "Copied!" : "Skopiowano!",
    "Not supported!" : "Nieobsługiwany!",
    "Press ⌘-C to copy." : "Wciśnij ⌘-C aby skopiować.",
    "Press Ctrl-C to copy." : "Wciśnij Ctrl-C aby skopiować.",
    "Choose a password for the public link" : "Wybierz hasło dla linku publicznego",
    "Password required" : "Wymagane hasło",
    "Filename" : "Nazwa pliku",
    "Password" : "Hasło",
    "Name" : "Nazwa",
    "Allow editing" : "Pozwól na edycję",
    "Edit link share: {name}" : "Edytuj link udostępniany: {name}",
    "Save" : "Zapisz",
    "Create link share: {name}" : "Utwórz link udostępniany: {name}",
    "Remove password" : "Usuń hasło",
    "Share to Twitter. Opens in a new window." : "Udostępnij na Twitter. Otwórz w nowym oknie.",
    "Share to Facebook. Opens in a new window." : "Udostępnij na Facebook. Otwórz w nowym oknie.",
    "Share to Diaspora. Opens in a new window." : "Udostępnij na Diaspora.  Otwórz w nowym oknie.",
    "Share to Google+. Opens in a new window." : "Udostępnij na Google+. Otwórz w nowym oknie.",
    "Share via email. Opens your mail client." : "Udostępnij poprzez e-mail. Otwórz Twojego klienta poczty e-mail.",
    "Error while sending notification" : "Błąd podczas wysyłania powiadomienia",
    "Sending ..." : "Wysyłanie...",
    "Email sent" : "E-mail wysłany",
    "Email link to person" : "Wyślij osobie odnośnik poprzez e-mail",
    "Send link via email" : "Wyślij link mailem",
    "Shared with you and the group {group} by {owner}" : "Udostępnione tobie i grupie {group} przez {owner}",
    "Shared with you by {owner}" : "Udostępnione tobie przez {owner}",
    "group" : "grupa",
    "remote" : "zdalny",
    "notify by email" : "powiadom przez emaila",
    "Unshare" : "Zatrzymaj współdzielenie",
    "can share" : "może współdzielić",
    "can edit" : "może edytować",
    "create" : "utwórz",
    "change" : "zmiany",
    "delete" : "usuń",
    "access control" : "kontrola dostępu",
    "Could not unshare" : "Nie udało się usunąć udostępnienia",
    "Share details could not be loaded for this item." : "Szczegóły udziału nie mogły zostać wczytane dla tego obiektu.",
    "No users or groups found for {search}" : "Nie znaleziono użytkowników lub grup dla {search}",
    "No users found for {search}" : "Nie znaleziono użytkowników dla {search}",
    "An error occurred. Please try again" : "Wystąpił błąd. Proszę spróbować ponownie.",
    "{sharee} (group)" : "{sharee} (grupa)",
    "{sharee} (at {server})" : "{sharee} (na {server})",
    "{sharee} (remote)" : "{sharee} (zdalny)",
    "Share" : "Udostępnij",
    "User and Groups" : "Użytkownicy i Grupy",
    "Public Links" : "Linki publiczne",
    "Resharing is not allowed" : "Współdzielenie nie jest możliwe",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Współdziel z użytkownikami innych chmur ownCloud używając wzorca uzytkownik@example.com/owncloud",
    "Share with users…" : "Współdziel z użytkownikami...",
    "Share with users, groups or remote users…" : "Współdziel z użytkownikami, grupami lub zdalnym użytkownikiem...",
    "Share with users or groups…" : "Współdziel z użytkownikami lub grupami...",
    "Share with users or remote users…" : "Współdziel z użytkownikami lub zdalnymi użytkownikami...",
    "Error removing share" : "Błąd podczas usuwania współdzielenia",
    "Warning" : "Ostrzeżenie",
    "Non-existing tag #{tag}" : "Znacznik #{tag} nie istnieje",
    "restricted" : "ograniczone",
    "invisible" : "niewidoczny",
    "({scope})" : "({scope})",
    "Delete" : "Usuń",
    "Rename" : "Zmień nazwę",
    "Collaborative tags" : "Znaczniki współpracy",
    "The object type is not specified." : "Nie określono typu obiektu.",
    "Enter new" : "Wpisz nowy",
    "Add" : "Dodaj",
    "Edit tags" : "Edytuj tagi",
    "Error loading dialog template: {error}" : "Błąd podczas ładowania szablonu dialogu: {error}",
    "No tags selected for deletion." : "Nie zaznaczono tagów do usunięcia.",
    "unknown text" : "nieznany tekst",
    "Hello world!" : "Witaj świecie!",
    "sunny" : "słoneczna",
    "Hello {name}, the weather is {weather}" : "Cześć {name}, dzisiejsza pogoda jest {weather}",
    "Hello {name}" : "Witaj {name}",
    "new" : "nowy",
    "_download %n file_::_download %n files_" : ["pobrano %n plik","pobrano %n plików","pobrano %n plików","pobrano %n plików"],
    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Trwa proces aktualizacji. Opuszczenie tej strony może przerwać ten proces.",
    "Updating to {version}" : "Uaktualnianie do {version}",
    "An error occurred." : "Wystąpił błąd",
    "Please reload the page." : "Proszę przeładować stronę",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Aktualizacja nie powiodła się. Aby dowiedzieć się więcej, <a href=\"{url}\">przeczytaj posta na forum</a> z dyskusją na ten temat.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Aktualizacja zakończyła się niepowodzeniem. Zgłoś ten problem <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">spoleczności ownCloud</a>.",
    "The update was successful. There were warnings." : "Aktualizacja przebiegła pomyślnie. Pojawiły się ostrzeżenia.",
    "The update was successful. Redirecting you to ownCloud now." : "Aktualizacji zakończyła się powodzeniem. Przekierowuję do ownCloud.",
    "Searching other places" : "Przeszukaj inne miejsca",
    "No search results in other folders" : "Brak wyników wyszukiwania w innych folderach",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} wynik wyszukiwania w innych folderach","{count} wyniki wyszukiwania w innych folderach","{count} wyniki wyszukiwania w innych folderach","{count} wyniki wyszukiwania w innych folderach"],
    "Personal" : "Osobiste",
    "Users" : "Użytkownicy",
    "Apps" : "Aplikacje",
    "Admin" : "Administrator",
    "Help" : "Pomoc",
    "Access forbidden" : "Dostęp zabroniony",
    "File not found" : "Nie odnaleziono pliku",
    "The specified document has not been found on the server." : "Wskazany dokument nie został znaleziony na serwerze.",
    "You can click here to return to %s." : "Możesz kliknąć tutaj aby powrócić do %s.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Witaj,\n\ntylko informuję, że %s współdzieli z Tobą %s.\nZobacz tutaj: %s\n\n",
    "The share will expire on %s." : "Ten zasób wygaśnie %s",
    "Cheers!" : "Pozdrawiam!",
    "Internal Server Error" : "Internal Server Error",
    "The server encountered an internal error and was unable to complete your request." : "Serwer napotkał błąd wewnętrzny i nie był w stanie ukończyć Twojego żądania.",
    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Proszę skontaktować się z administratorem jeśli ten błąd będzie się pojawiał wielokrotnie, proszę do zgłoszenia dołączyć szczegóły techniczne opisane poniżej.",
    "More details can be found in the server log." : "Więcej szczegółów można znaleźć w logu serwera.",
    "Technical details" : "Szczegóły techniczne",
    "Remote Address: %s" : "Adres zdalny: %s",
    "Request ID: %s" : "ID żądania: %s",
    "Type: %s" : "Typ: %s",
    "Code: %s" : "Kod: %s",
    "Message: %s" : "Komunikat: %s",
    "File: %s" : "Plik: %s",
    "Line: %s" : "Linia: %s",
    "Trace" : "Ślad",
    "Create an <strong>admin account</strong>" : "Utwórz <strong>konta administratora</strong>",
    "Username" : "Nazwa użytkownika",
    "Storage & database" : "Zasoby dysku & baza danych",
    "Data folder" : "Katalog danych",
    "Configure the database" : "Skonfiguruj bazę danych",
    "Only %s is available." : "Dostępne jest wyłącznie %s.",
    "Install and activate additional PHP modules to choose other database types." : "Zainstaluj lub aktywuj dodatkowe moduły PHP, aby uzyskać możliwość wyboru innych typów baz danych.",
    "For more details check out the documentation." : "Aby uzyskać więcej informacji zapoznaj się z dokumentacją.",
    "Database user" : "Użytkownik bazy danych",
    "Database password" : "Hasło do bazy danych",
    "Database name" : "Nazwa bazy danych",
    "Database tablespace" : "Obszar tabel bazy danych",
    "Database host" : "Komputer bazy danych",
    "Please specify the port number along with the host name (e.g., localhost: 5432)." : "Wraz z nazwą hosta należy podać numer portu  (np. localhost: 5432).",
    "Performance warning" : "Ostrzeżenie o wydajności",
    "SQLite will be used as database." : "SQLite będzie używane jako baza danych.",
    "For larger installations we recommend to choose a different database backend." : "Dla większych instalacji zalecamy użycie innego rodzaju bazy danych.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Zwłaszcza w przypadku używania programu klienta do synchronizacji plików użycie bazy SQLite  jest niezalecane.",
    "Finish setup" : "Zakończ konfigurowanie",
    "Finishing …" : "Kończę ...",
    "Need help?" : "Potrzebujesz pomocy?",
    "See the documentation" : "Zapoznaj się z dokumentacją",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Witam, <br><br>informuję, że %s udostępnianych zasobów <strong>%s</strong> jest z Tobą.<br><a href=\"%s\">Zobacz!</a><br><br>",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Ta aplikacja wymaga JavaScript do poprawnego działania. Proszę {linkstart}włączyć JavaScript{linkend} i przeładować stronę.",
    "Log out" : "Wyloguj",
    "Search" : "Wyszukaj",
    "Server side authentication failed!" : "Uwierzytelnianie po stronie serwera nie powiodło się!",
    "Please contact your administrator." : "Skontaktuj się z administratorem",
    "An internal error occurred." : "Wystąpił wewnętrzny błąd.",
    "Please try again or contact your administrator." : "Spróbuj ponownie lub skontaktuj się z administratorem.",
    "Username or email" : "Nazwa użytkownika lub adres e-mail",
    "Log in" : "Zaloguj",
    "Wrong password. Reset it?" : "Niepoprawne hasło? Zresetuj je!",
    "Wrong password." : "Złe hasło",
    "Stay logged in" : "Pozostań zalogowany",
    "Alternative Logins" : "Alternatywne loginy",
    "Use the following link to reset your password: {link}" : "Użyj tego odnośnika by zresetować hasło: {link}",
    "Password changed successfully" : "Pomyślnie zmieniono hasło",
    "New password" : "Nowe hasło",
    "New Password" : "Nowe hasło",
    "Reset password" : "Zresetuj hasło",
    "This ownCloud instance is currently in single user mode." : "Ta instalacja ownCloud działa obecnie w trybie pojedynczego użytkownika.",
    "This means only administrators can use the instance." : "To oznacza, że tylko administratorzy mogą w tej chwili używać aplikacji.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Skontaktuj się z administratorem, jeśli ten komunikat pojawił się nieoczekiwanie lub wyświetla się ciągle.",
    "Thank you for your patience." : "Dziękuję za cierpliwość.",
    "Two-step verification" : "Weryfikacja dwuskładnikowa",
    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "Dla Twojego konta uruchomiono wzmocnioną ochronę. Uwierzytelnij przy pomocy drugiego składnika.",
    "Cancel login" : "Anuluj logowanie",
    "Please authenticate using the selected factor." : "Uwierzytelnij przy pomocy wybranego składnika",
    "An error occurred while verifying the token" : "Wystąpił błąd podczas weryfikacji tokena",
    "You are accessing the server from an untrusted domain." : "Dostajesz się do serwera z niezaufanej domeny.",
    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Skontaktuj się z administratorem. Jeśli jesteś administratorem tej instancji, skonfiguruj parametr \"trusted_domains\" w pliku config/config.php. Przykładowa konfiguracja znajduje się w pliku config/ config.sample.php.",
    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "W zależności od konfiguracji, jako administrator możesz także użyć poniższego przycisku aby zaufać tej domenie.",
    "Add \"%s\" as trusted domain" : "Dodaj \"%s\" jako domenę zaufaną",
    "App update required" : "Aktualizacja aplikacji wymagana",
    "%s will be updated to version %s" : "%s zostanie zaktualizowane do wersji %s",
    "These apps will be updated:" : "Te aplikacje zostaną zaktualizowane:",
    "The theme %s has been disabled." : "Motyw %s został wyłączony.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Proszę się upewnić, że baza danych, folder konfiguracji oraz folder danych zostały zarchiwizowane przed przejściem dalej.",
    "Start update" : "Rozpocznij aktualizację",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Aby uniknąć timeout-ów przy większych instalacjach, możesz zamiast tego uruchomić następującą komendę w katalogu Twojej instalacji:",
    "Detailed logs" : "Szczegółowe logi",
    "Update needed" : "Wymagana aktualizacja",
    "Please use the command line updater because you have a big instance." : "Ze względu na rozmiar Twojej instalacji użyj programu do aktualizacji z linii poleceń.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Aby uzyskać pomoc, zajrzyj do <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentacji</a>.",
    "This %s instance is currently in maintenance mode, which may take a while." : "Ta %s instancja jest obecnie w trybie serwisowym, co może potrwać chwilę.",
    "This page will refresh itself when the %s instance is available again." : "Strona odświeży się gdy instancja %s będzie ponownie dostępna.",
    "Could not reset password because the token is invalid" : "Nie można zresetować hasła: nieprawidłowy token.",
    "Could not reset password because the token expired" : "Nie można zresetować hasła: token wygasł.",
    "Could not reset password because the token does not match" : "Nie można zresetować hasła: nieprawidłowy token.",
    "Copy to clipboard" : "Skopiuj do schowka",
    "Choose a password" : "Wprowadź hasło",
    "Menu" : "Menu",
    "Email notification not sent" : "Powiadomienie email nie zostało wysłane",
    "Link name" : "Nazwa linku",
    "Email notification was sent!" : "Powiadomienie email zostało wysłane",
    "Sending" : "Wysyłanie",
    "Imprint" : "Stopka",
    "Owner: {owner}" : "Właściciel: {owner}",
    "You are trying to access a private link. Please log in first." : "Próbujesz dostępu do prywatnego linku. Proszę się najpierw zalogować.",
    "Couldn't send mail to following recipient(s): %s " : "Nie udało się wysłać wiadomości do odbiorcy(ów): %s ",
    "Choose an expiration date" : "Wybierz datę wygaśnięcia",
    "Send copy to self" : "Wyślij kopię do siebie",
    "Add personal message" : "Dodaj własną wiadomość",
    "Upload only" : "Tylko wysyłanie",
    "Error adding {addItem}: {addItem} already exists" : "Błąd dodawania {addItem}: {addItem} już istnieje",
    "Download / View" : "Pobieranie / Podgląd",
    "Recipients can view or download contents." : "Odbiorcy mogą otwierać lub pobierać zawartość.",
    "Download / View / Upload" : "Pobieranie / Podgląd / Wysyłanie",
    "Recipients can view, download, edit, delete and upload contents." : "Odbiorcy mogą otwierać, pobierać, zmieniać, kasować i wysyłać zawartość.",
    "An error occured while sending email" : "Wystąpił błąd przy wysyłaniu wiadomości email",
    "E-Mail sent" : "Wiadomość e-mail została wysłana",
    "federated" : "stowarzyszona",
    "Personal note from the sender: %s." : "Własna informacja od nadawcy: %s."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>=14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
